pywurfl.algorithms.wurfl.handlers.AndroidMatcher

Package pywurfl :: Package algorithms :: Package wurfl :: Module handlers :: Class AndroidMatcher |
[hide private]
[frames] | no frames]

# Class AndroidMatcher

source code

         object --+
                  |
    AbstractMatcher --+
                      |
                     AndroidMatcher

Instance Methods | [hide private]
can_handle(self, user_agent) | source code
look_for_matching_user_agent(self, user_agent) | source code
recovery_match(self, user_agent) | source code
Inherited from `AbstractMatcher`: `__call__`, `__init__`, `add`, `catch_all_recovery_match`, `conclusive_match` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `AbstractMatcher`: `recovery_map`, `user_agent_map`

Properties | [hide private]
Inherited from `AbstractMatcher`: `user_agents` Inherited from `object`: `__class__`

Method Details | [hide private]

### can_handle(self, user_agent) | source code
Overrides: AbstractMatcher.can_handle

### look_for_matching_user_agent(self, user_agent) | source code
Overrides: AbstractMatcher.look_for_matching_user_agent

### recovery_match(self, user_agent) | source code
Overrides: AbstractMatcher.recovery_match